Toplogy
=======

command : linchpin topology

This command lists all the topology available and copies layouts to the layouts folder in current working directory.


Options :
  get      gets toplogy by name. 
  list     lists all the topologies packaged

=========
Examples:
=========

+------------------------+----------------------------------------------------+
| Usage                  | Action                                             |
+------------------------+----------------------------------------------------+
| linchpin topology list | Lists all the topologies packaged in linchpin      |
+------------------------+----------------------------------------------------+
+ linchpin topology get  + Copies the topology file from the package by name  +
| <layoutname>           |  into layouts folder of current working directory. |
+------------------------+----------------------------------------------------+
